---
id: 20211123220309
title: Override previous / next page to follow the sequence of Zettelkasten IDs
tags: [navigation, zettel]
---

# Override previous / next page to follow the sequence of Zettelkasten IDs

By default MkDocs provides buttons linking to [previous / next page](https://www.mkdocs.org/dev-guide/themes/#pageprevious_page) based on the list of navigation items.

In Zettelkasten, it can be useful to go through the zettels in the order in which they were taken. This is a logical connection too. Checking the adjacent zettels may lead to new ideas.
